This function query and returns the EIOPA risk-free interest rate term structures from an API.
Note: this function is getting the data from an API. Your IP can be temporary or permanently blocked if too many queries are executed.
For optimal performance, we recommend to limit the number of calls to this function.
EIOPA website : https://www.eiopa.europa.eu/tools-and-data/risk-free-interest-rate-term-structures_en